<p align="center">
  <a href="https://feishu.adapters.nonebot.dev/">
    <img src="https://feishu.adapters.nonebot.dev/logo.png" width="200" height="200" alt="nonebot-adapter-feishu">
  </a>
</p>

<div align="center">

# NoneBot-Adapter-Feishu

<!-- prettier-ignore-start -->
<!-- markdownlint-disable-next-line MD036 -->
_✨ 飞书协议适配 ✨_
<!-- prettier-ignore-end -->

</div>

<p align="center">
  <a href="https://raw.githubusercontent.com/nonebot/adapter-feishu/master/LICENSE">
    <img src="https://img.shields.io/github/license/nonebot/adapter-feishu" alt="license">
  </a>
  <a href="https://pypi.python.org/pypi/nonebot-adapter-feishu">
    <img src="https://img.shields.io/pypi/v/nonebot-adapter-feishu" alt="pypi">
  </a>
  <img src="https://img.shields.io/badge/python-3.8+-blue" alt="python">
  <a href="https://codecov.io/gh/nonebot/adapter-feishu">
    <img src="https://codecov.io/gh/nonebot/adapter-feishu/branch/master/graph/badge.svg?token=45OH1IVM9C"/>
  </a>
  <a href="https://github.com/nonebot/adapter-feishu/actions/workflows/website-deploy.yml">
    <img src="https://github.com/nonebot/adapter-feishu/actions/workflows/website-deploy.yml/badge.svg?branch=master&event=push" alt="site"/>
  </a>
  <a href="https://results.pre-commit.ci/latest/github/nonebot/adapter-feishu/master">
    <img src="https://results.pre-commit.ci/badge/github/nonebot/adapter-feishu/master.svg" />
  </a>
  <br />
  <a href="https://jq.qq.com/?_wv=1027&k=5OFifDh">
    <img src="https://img.shields.io/badge/QQ%E7%BE%A4-768887710-orange?style=flat-square" alt="QQ Chat Group">
  </a>
  <a href="https://qun.qq.com/qqweb/qunpro/share?_wv=3&_wwv=128&appChannel=share&inviteCode=7b4a3&appChannel=share&businessType=9&from=246610&biz=ka">
    <img src="https://img.shields.io/badge/QQ%E9%A2%91%E9%81%93-NoneBot-5492ff?style=flat-square" alt="QQ Channel">
  </a>
  <a href="https://t.me/botuniverse">
    <img src="https://img.shields.io/badge/telegram-botuniverse-blue?style=flat-square" alt="Telegram Channel">
  </a>
  <a href="https://discord.gg/VKtE6Gdc4h">
    <img src="https://discordapp.com/api/guilds/847819937858584596/widget.png?style=shield" alt="Discord Server">
  </a>
</p>

<p align="center">
  <a href="https://feishu.adapters.nonebot.dev/">文档</a>
  ·
  <a href="https://feishu.adapters.nonebot.dev/docs/guide/installation">安装</a>
  ·
  <a href="https://feishu.adapters.nonebot.dev/docs/guide/setup">开始使用</a>
</p>
